# condax

Condax is inpired by the excellent [pipx](https://github.com/pipxproject/pipx), and attempts to do something similar, just using conda thus lifting the constraints of only packaging python things.

## Installation

condax is distributed on [PyPI](https://pypi.org) as a universal
wheel and is available on Linux and macOS and supports
Python 3.5+ and PyPy.

```bash
$ pip install condax
```

## License

condax is distributed under the terms of the
[MIT License](https://choosealicense.com/licenses/mit).
